package vip.xiaonuo.modular.InternalCar.controller;/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */


import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.InternalCar.entity.InternalCar;
import vip.xiaonuo.modular.InternalCar.param.InternalCarAddParam;
import vip.xiaonuo.modular.InternalCar.param.InternalCarEditParam;
import vip.xiaonuo.modular.InternalCar.param.InternalCarIdParam;
import vip.xiaonuo.modular.InternalCar.param.InternalCarPageParam;
import vip.xiaonuo.modular.InternalCar.service.InternalCarService;


import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * internal_car控制器
 *
 * @author wang
 * @date  2023/12/05 16:29
 */
@Api(tags = "internal_car控制器")
@ApiSupport(author = "HUIMV", order = 1)
@RestController
@Validated
public class InternalCarController {

    @Resource
    private InternalCarService internalCarService;

    /**
     * 获取internal_car分页
     *
     * @author wang
     * @date  2023/12/05 16:29
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取internal_car分页")
    @GetMapping("/biz/car/page")
    public CommonResult<Page<InternalCar>> page(InternalCarPageParam internalCarPageParam) {
        return CommonResult.data(internalCarService.page(internalCarPageParam));
    }

    /**
     * 添加internal_car
     *
     * @author wang
     * @date  2023/12/05 16:29
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加internal_car")
    @CommonLog("添加internal_car")
    @PostMapping("/biz/car/add")
    public CommonResult<String> add(@RequestBody @Valid InternalCarAddParam internalCarAddParam) {
        return internalCarService.add(internalCarAddParam);
    }

    /**
     * 编辑internal_car
     *
     * @author wang
     * @date  2023/12/05 16:29
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑internal_car")
    @CommonLog("编辑internal_car")
    @PostMapping("/biz/car/edit")
    public CommonResult<String> edit(@RequestBody @Valid InternalCarEditParam internalCarEditParam) {
        return internalCarService.edit(internalCarEditParam);
    }

    /**
     * 删除internal_car
     *
     * @author wang
     * @date  2023/12/05 16:29
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除internal_car")
    @CommonLog("删除internal_car")
    @PostMapping("/biz/car/delete")
    public CommonResult<String> delete(@RequestBody  @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<InternalCarIdParam> internalCarIdParamList) {
        internalCarService.delete(internalCarIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取internal_car详情
     *
     * @author wang
     * @date  2023/12/05 16:29
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取internal_car详情")
    @GetMapping("/biz/car/detail")
    public CommonResult<InternalCar> detail(@Valid InternalCarIdParam internalCarIdParam) {
        return CommonResult.data(internalCarService.detail(internalCarIdParam));
    }
}
