/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigablactation.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.modular.bi.pigablactation.entity.PigAblactation;
import vip.xiaonuo.modular.bi.pigablactation.mapper.PigAblactationMapper;
import vip.xiaonuo.modular.bi.pigablactation.param.PigAblactationAddParam;
import vip.xiaonuo.modular.bi.pigablactation.param.PigAblactationEditParam;
import vip.xiaonuo.modular.bi.pigablactation.param.PigAblactationIdParam;
import vip.xiaonuo.modular.bi.pigablactation.param.PigAblactationPageParam;
import vip.xiaonuo.modular.bi.pigablactation.service.PigAblactationService;

import java.util.List;

/**
 * 断奶信息Service接口实现类
 *
 * @author wang
 * @date  2023/12/07 14:03
 **/
@Service
public class PigAblactationServiceImpl extends ServiceImpl<PigAblactationMapper, PigAblactation> implements PigAblactationService {

    @Override
    public Page<PigAblactation> page(PigAblactationPageParam pigAblactationPageParam) {
        QueryWrapper<PigAblactation> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigAblactationPageParam.getEartag())) {
            queryWrapper.lambda().like(PigAblactation::getEartag, pigAblactationPageParam.getEartag());
        }
        if(ObjectUtil.isNotEmpty(pigAblactationPageParam.getStartAblactationDate()) && ObjectUtil.isNotEmpty(pigAblactationPageParam.getEndAblactationDate())) {
            queryWrapper.lambda().between(PigAblactation::getAblactationDate, pigAblactationPageParam.getStartAblactationDate(), pigAblactationPageParam.getEndAblactationDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigAblactationPageParam.getSortField(), pigAblactationPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigAblactationPageParam.getSortOrder());
            queryWrapper.orderBy(true, pigAblactationPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigAblactationPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigAblactation::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PigAblactationAddParam pigAblactationAddParam) {
        PigAblactation pigAblactation = BeanUtil.toBean(pigAblactationAddParam, PigAblactation.class);
        this.save(pigAblactation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PigAblactationEditParam pigAblactationEditParam) {
        PigAblactation pigAblactation = this.queryEntity(pigAblactationEditParam.getId());
        BeanUtil.copyProperties(pigAblactationEditParam, pigAblactation);
        this.updateById(pigAblactation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigAblactationIdParam> pigAblactationIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigAblactationIdParamList, PigAblactationIdParam::getId));
    }

    @Override
    public PigAblactation detail(PigAblactationIdParam pigAblactationIdParam) {
        return this.queryEntity(pigAblactationIdParam.getId());
    }

    @Override
    public PigAblactation queryEntity(Integer id) {
        PigAblactation pigAblactation = this.getById(id);
        if(ObjectUtil.isEmpty(pigAblactation)) {
            throw new CommonException("断奶信息不存在，id值为：{}", id);
        }
        return pigAblactation;
    }
}
