/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigbackfat.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.modular.bi.pigbackfat.entity.PigBackfat;
import vip.xiaonuo.modular.bi.pigbackfat.mapper.PigBackfatMapper;
import vip.xiaonuo.modular.bi.pigbackfat.param.PigBackfatAddParam;
import vip.xiaonuo.modular.bi.pigbackfat.param.PigBackfatEditParam;
import vip.xiaonuo.modular.bi.pigbackfat.param.PigBackfatIdParam;
import vip.xiaonuo.modular.bi.pigbackfat.param.PigBackfatPageParam;
import vip.xiaonuo.modular.bi.pigbackfat.service.PigBackfatService;

import java.util.List;

/**
 * 背膘测定Service接口实现类
 *
 * @author wang
 * @date  2023/12/07 17:54
 **/
@Service
public class PigBackfatServiceImpl extends ServiceImpl<PigBackfatMapper, PigBackfat> implements PigBackfatService {

    @Override
    public Page<PigBackfat> page(PigBackfatPageParam pigBackfatPageParam) {
        QueryWrapper<PigBackfat> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigBackfatPageParam.getEartag())) {
            queryWrapper.lambda().like(PigBackfat::getEartag, pigBackfatPageParam.getEartag());
        }
        if(ObjectUtil.isNotEmpty(pigBackfatPageParam.getStartThisDate()) && ObjectUtil.isNotEmpty(pigBackfatPageParam.getEndThisDate())) {
            queryWrapper.lambda().between(PigBackfat::getThisDate, pigBackfatPageParam.getStartThisDate(), pigBackfatPageParam.getEndThisDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigBackfatPageParam.getSortField(), pigBackfatPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigBackfatPageParam.getSortOrder());
            queryWrapper.orderBy(true, pigBackfatPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigBackfatPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigBackfat::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PigBackfatAddParam pigBackfatAddParam) {
        PigBackfat pigBackfat = BeanUtil.toBean(pigBackfatAddParam, PigBackfat.class);
        this.save(pigBackfat);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PigBackfatEditParam pigBackfatEditParam) {
        PigBackfat pigBackfat = this.queryEntity(pigBackfatEditParam.getId());
        BeanUtil.copyProperties(pigBackfatEditParam, pigBackfat);
        this.updateById(pigBackfat);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigBackfatIdParam> pigBackfatIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigBackfatIdParamList, PigBackfatIdParam::getId));
    }

    @Override
    public PigBackfat detail(PigBackfatIdParam pigBackfatIdParam) {
        return this.queryEntity(pigBackfatIdParam.getId());
    }

    @Override
    public PigBackfat queryEntity(Integer id) {
        PigBackfat pigBackfat = this.getById(id);
        if(ObjectUtil.isEmpty(pigBackfat)) {
            throw new CommonException("背膘测定不存在，id值为：{}", id);
        }
        return pigBackfat;
    }
}
