/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigdeath.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.modular.bi.pigbatch.entity.PigBatch;
import vip.xiaonuo.modular.bi.pigdeath.entity.PigDeath;
import vip.xiaonuo.modular.bi.pigdeath.mapper.PigDeathMapper;
import vip.xiaonuo.modular.bi.pigdeath.param.PigDeathAddParam;
import vip.xiaonuo.modular.bi.pigdeath.param.PigDeathEditParam;
import vip.xiaonuo.modular.bi.pigdeath.param.PigDeathIdParam;
import vip.xiaonuo.modular.bi.pigdeath.param.PigDeathPageParam;
import vip.xiaonuo.modular.bi.pigdeath.service.PigDeathService;


import java.util.Date;
import java.util.List;

/**
 * 死亡信息Service接口实现类
 *
 * @author wang
 * @date  2023/12/07 17:36
 **/
@Service
public class PigDeathServiceImpl extends ServiceImpl<PigDeathMapper, PigDeath> implements PigDeathService {
    @Autowired
    private PigDeathMapper deathMapper;

    @Override
    public Page<PigDeath> page(PigDeathPageParam pigDeathPageParam) {
        QueryWrapper<PigDeath> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigDeathPageParam.getEartag())) {
            queryWrapper.lambda().like(PigDeath::getEartag, pigDeathPageParam.getEartag());
        }
        if(ObjectUtil.isNotEmpty(pigDeathPageParam.getStartDeathDate()) && ObjectUtil.isNotEmpty(pigDeathPageParam.getEndDeathDate())) {
            queryWrapper.lambda().between(PigDeath::getDeathDate, pigDeathPageParam.getStartDeathDate(), pigDeathPageParam.getEndDeathDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigDeathPageParam.getSortField(), pigDeathPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigDeathPageParam.getSortOrder());
            queryWrapper.orderBy(true, pigDeathPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigDeathPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigDeath::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CommonResult add(PigDeathAddParam pigDeathAddParam) {
        QueryWrapper<PigDeath> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id", pigDeathAddParam.getOrgId()).eq("eartag", pigDeathAddParam.getEartag());
        if (ObjectUtil.isEmpty(deathMapper.selectOne(queryWrapper))) {
            PigDeath pigDeath = BeanUtil.toBean(pigDeathAddParam, PigDeath.class);
            pigDeath.setCreateDate(new Date());
            this.save(pigDeath);
            return CommonResult.ok();
        } else {
            return new CommonResult(500, "耳标号已存在，请重新添加！", false);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CommonResult edit(PigDeathEditParam pigDeathEditParam) {
        PigDeath pigDeath = this.queryEntity(pigDeathEditParam.getId());
        if (ObjectUtil.isNotEmpty(pigDeathEditParam.getEartag())) {
            QueryWrapper<PigDeath> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", pigDeath.getOrgId())
                    .eq(StringUtils.isNotBlank(pigDeathEditParam.getEartag()),"eartag",pigDeathEditParam.getEartag())
                    .ne("id", pigDeathEditParam.getId());
            if (ObjectUtil.isEmpty(deathMapper.selectOne(queryWrapper))) {
                BeanUtil.copyProperties(pigDeathEditParam, pigDeath);
                this.updateById(pigDeath);
                return CommonResult.ok();
            } else {
                return new CommonResult(500, "耳标号已存在！", false);
            }
        } else {
            BeanUtil.copyProperties(pigDeathEditParam, pigDeath);
            this.updateById(pigDeath);
            return CommonResult.ok();
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigDeathIdParam> pigDeathIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigDeathIdParamList, PigDeathIdParam::getId));
    }

    @Override
    public PigDeath detail(PigDeathIdParam pigDeathIdParam) {
        return this.queryEntity(pigDeathIdParam.getId());
    }

    @Override
    public PigDeath queryEntity(Integer id) {
        PigDeath pigDeath = this.getById(id);
        if(ObjectUtil.isEmpty(pigDeath)) {
            throw new CommonException("死亡信息不存在，id值为：{}", id);
        }
        return pigDeath;
    }
}
