/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigdeliver.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.modular.bi.pigdeliver.param.PigDeliverPageParam;
import vip.xiaonuo.modular.bi.pigdeliver.service.PigDeliverService;
import vip.xiaonuo.modular.bi.pigdeliver.entity.PigDeliver;
import vip.xiaonuo.modular.bi.pigdeliver.mapper.PigDeliverMapper;
import vip.xiaonuo.modular.bi.pigdeliver.param.PigDeliverAddParam;
import vip.xiaonuo.modular.bi.pigdeliver.param.PigDeliverEditParam;
import vip.xiaonuo.modular.bi.pigdeliver.param.PigDeliverIdParam;


import java.util.Date;
import java.util.List;

/**
 * 母猪分娩Service接口实现类
 *
 * @author wang
 * @date  2023/12/07 10:38
 **/
@Service
public class PigDeliverServiceImpl extends ServiceImpl<PigDeliverMapper, PigDeliver> implements PigDeliverService {

    @Override
    public Page<PigDeliver> page(PigDeliverPageParam pigDeliverPageParam) {
        QueryWrapper<PigDeliver> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigDeliverPageParam.getEartag())) {
            queryWrapper.lambda().like(PigDeliver::getEartag, pigDeliverPageParam.getEartag());
        }
        if(ObjectUtil.isNotEmpty(pigDeliverPageParam.getStartDeliverDate()) && ObjectUtil.isNotEmpty(pigDeliverPageParam.getEndDeliverDate())) {
            queryWrapper.lambda().between(PigDeliver::getDeliverDate, pigDeliverPageParam.getStartDeliverDate(), pigDeliverPageParam.getEndDeliverDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigDeliverPageParam.getSortField(), pigDeliverPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigDeliverPageParam.getSortOrder());
            queryWrapper.orderBy(true, pigDeliverPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigDeliverPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigDeliver::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PigDeliverAddParam pigDeliverAddParam) {
        PigDeliver pigDeliver = BeanUtil.toBean(pigDeliverAddParam, PigDeliver.class);
        pigDeliver.setCreateDate(new Date());
        this.save(pigDeliver);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PigDeliverEditParam pigDeliverEditParam) {
        PigDeliver pigDeliver = this.queryEntity(pigDeliverEditParam.getId());
        BeanUtil.copyProperties(pigDeliverEditParam, pigDeliver);
        this.updateById(pigDeliver);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigDeliverIdParam> pigDeliverIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigDeliverIdParamList, PigDeliverIdParam::getId));
    }

    @Override
    public PigDeliver detail(PigDeliverIdParam pigDeliverIdParam) {
        return this.queryEntity(pigDeliverIdParam.getId());
    }

    @Override
    public PigDeliver queryEntity(Integer id) {
        PigDeliver pigDeliver = this.getById(id);
        if(ObjectUtil.isEmpty(pigDeliver)) {
            throw new CommonException("母猪分娩不存在，id值为：{}", id);
        }
        return pigDeliver;
    }
}
