/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigeliminate.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.modular.bi.pigdeath.entity.PigDeath;
import vip.xiaonuo.modular.bi.pigeliminate.entity.PigEliminate;
import vip.xiaonuo.modular.bi.pigeliminate.mapper.PigEliminateMapper;
import vip.xiaonuo.modular.bi.pigeliminate.param.PigEliminateAddParam;
import vip.xiaonuo.modular.bi.pigeliminate.param.PigEliminateEditParam;
import vip.xiaonuo.modular.bi.pigeliminate.param.PigEliminateIdParam;
import vip.xiaonuo.modular.bi.pigeliminate.param.PigEliminatePageParam;
import vip.xiaonuo.modular.bi.pigeliminate.service.PigEliminateService;

import java.util.Date;
import java.util.List;

/**
 * 淘汰信息Service接口实现类
 *
 * @author wang
 * @date  2023/12/08 09:14
 **/
@Service
public class PigEliminateServiceImpl extends ServiceImpl<PigEliminateMapper, PigEliminate> implements PigEliminateService {

    @Autowired
    private PigEliminateMapper eliminateMapper;
    @Override
    public Page<PigEliminate> page(PigEliminatePageParam pigEliminatePageParam) {
        QueryWrapper<PigEliminate> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigEliminatePageParam.getEartag())) {
            queryWrapper.lambda().like(PigEliminate::getEartag, pigEliminatePageParam.getEartag());
        }
        if(ObjectUtil.isNotEmpty(pigEliminatePageParam.getStartEliminateDate()) && ObjectUtil.isNotEmpty(pigEliminatePageParam.getEndEliminateDate())) {
            queryWrapper.lambda().between(PigEliminate::getEliminateDate, pigEliminatePageParam.getStartEliminateDate(), pigEliminatePageParam.getEndEliminateDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigEliminatePageParam.getSortField(), pigEliminatePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigEliminatePageParam.getSortOrder());
            queryWrapper.orderBy(true, pigEliminatePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigEliminatePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigEliminate::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CommonResult add(PigEliminateAddParam pigEliminateAddParam) {
        QueryWrapper<PigEliminate> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id", pigEliminateAddParam.getOrgId()).eq("eartag", pigEliminateAddParam.getEartag());
        if (ObjectUtil.isEmpty(eliminateMapper.selectOne(queryWrapper))) {
            PigEliminate pigEliminate = BeanUtil.toBean(pigEliminateAddParam, PigEliminate.class);
            pigEliminate.setCreateDate(new Date());
            this.save(pigEliminate);
            return CommonResult.ok();
        } else {
            return new CommonResult(500, "添加失败！耳标号已存在！", false);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public CommonResult edit(PigEliminateEditParam pigEliminateEditParam) {
        PigEliminate pigEliminate = this.queryEntity(pigEliminateEditParam.getId());
        if (ObjectUtil.isNotEmpty(pigEliminateEditParam.getEartag())) {
            QueryWrapper<PigEliminate> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", pigEliminate.getOrgId())
                    .eq(StringUtils.isNotBlank(pigEliminateEditParam.getEartag()),"eartag",pigEliminateEditParam.getEartag())
                    .ne("id", pigEliminateEditParam.getId());
            if (ObjectUtil.isEmpty(eliminateMapper.selectOne(queryWrapper))) {
                BeanUtil.copyProperties(pigEliminateEditParam, pigEliminate);
                this.updateById(pigEliminate);
                return CommonResult.ok();
            } else {
                return new CommonResult(500, "耳标号已存在！", false);
            }
        } else {
            BeanUtil.copyProperties(pigEliminateEditParam, pigEliminate);
            this.updateById(pigEliminate);
            return CommonResult.ok();
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigEliminateIdParam> pigEliminateIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigEliminateIdParamList, PigEliminateIdParam::getId));
    }

    @Override
    public PigEliminate detail(PigEliminateIdParam pigEliminateIdParam) {
        return this.queryEntity(pigEliminateIdParam.getId());
    }

    @Override
    public PigEliminate queryEntity(Integer id) {
        PigEliminate pigEliminate = this.getById(id);
        if(ObjectUtil.isEmpty(pigEliminate)) {
            throw new CommonException("淘汰信息不存在，id值为：{}", id);
        }
        return pigEliminate;
    }
}
