/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigfiles.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.bi.pigfiles.entity.PigFiles;
import vip.xiaonuo.modular.bi.pigfiles.param.PigFilesAddParam;
import vip.xiaonuo.modular.bi.pigfiles.param.PigFilesEditParam;
import vip.xiaonuo.modular.bi.pigfiles.param.PigFilesIdParam;
import vip.xiaonuo.modular.bi.pigfiles.param.PigFilesPageParam;
import vip.xiaonuo.modular.bi.pigfiles.service.PigFilesService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 猪只档案控制器
 *
 * @author wang
 * @date  2023/12/06 14:33
 */
@Api(tags = "猪只档案控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class PigFilesController {

    @Resource
    private PigFilesService pigFilesService;

    /**
     * 获取猪只档案分页
     *
     * @author wang
     * @date  2023/12/06 14:33
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取猪只档案分页")
    @GetMapping("/bi/pigfiles/page")
    public CommonResult<Page<PigFiles>> page(PigFilesPageParam pigFilesPageParam) {
        return CommonResult.data(pigFilesService.page(pigFilesPageParam));
    }

    /**
     * 添加猪只档案
     *
     * @author wang
     * @date  2023/12/06 14:33
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加猪只档案")
    @CommonLog("添加猪只档案")
    @PostMapping("/bi/pigfiles/add")
    public CommonResult<String> add(@RequestBody @Valid PigFilesAddParam pigFilesAddParam) {
        return pigFilesService.add(pigFilesAddParam);
    }

    /**
     * 编辑猪只档案
     *
     * @author wang
     * @date  2023/12/06 14:33
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑猪只档案")
    @CommonLog("编辑猪只档案")
    @PostMapping("/bi/pigfiles/edit")
    public CommonResult<String> edit(@RequestBody @Valid PigFilesEditParam pigFilesEditParam) {
        return  pigFilesService.edit(pigFilesEditParam);
    }

    /**
     * 删除猪只档案
     *
     * @author wang
     * @date  2023/12/06 14:33
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除猪只档案")
    @CommonLog("删除猪只档案")
    @PostMapping("/bi/pigfiles/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PigFilesIdParam> pigFilesIdParamList) {
        pigFilesService.delete(pigFilesIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取猪只档案详情
     *
     * @author wang
     * @date  2023/12/06 14:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取猪只档案详情")
    @GetMapping("/bi/pigfiles/detail")
    public CommonResult<PigFiles> detail(@Valid PigFilesIdParam pigFilesIdParam) {
        return CommonResult.data(pigFilesService.detail(pigFilesIdParam));
    }
}
