/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.feed.feedinglist.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.feed.feedinglist.entity.FeedingList;
import vip.xiaonuo.modular.feed.feedinglist.param.FeedingListAddParam;
import vip.xiaonuo.modular.feed.feedinglist.param.FeedingListEditParam;
import vip.xiaonuo.modular.feed.feedinglist.param.FeedingListIdParam;
import vip.xiaonuo.modular.feed.feedinglist.param.FeedingListPageParam;
import vip.xiaonuo.modular.feed.feedinglist.service.FeedingListService;
import vip.xiaonuo.modular.feed.feedinglist.vo.FeedingListVo;
import vip.xiaonuo.modular.feed.feedinglist.vo.FeedingListVo2;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 料塔控制器
 *
 * @author wang
 * @date  2023/12/27 15:34
 */
@Api(tags = "料塔控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class FeedingListController {

    @Resource
    private FeedingListService feedingListService;

    /**
     * 获取料塔分页
     *
     * @author wang
     * @date  2023/12/27 15:34
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取料塔分页")
    @GetMapping("/modular/feedinglist/page")
    public CommonResult<Page<FeedingList>> page(FeedingListPageParam feedingListPageParam) {
        return CommonResult.data(feedingListService.page(feedingListPageParam));
    }

    /**
     * 添加料塔
     *
     * @author wang
     * @date  2023/12/27 15:34
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加料塔")
    @CommonLog("添加料塔")
    @PostMapping("/modular/feedinglist/add")
    public CommonResult<String> add(@RequestBody @Valid FeedingListAddParam feedingListAddParam) {
        feedingListService.add(feedingListAddParam);
        return CommonResult.ok();
    }



    /**
     * 获取料塔列表
     *
     * @author wang
     * @date  2023/12/27 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取料塔详情")
    @GetMapping("/modular/feedinglist/listFeed")
    public CommonResult<List<FeedingListVo>> listFeed(@Valid FeedingListIdParam feedingListIdParam) {
        return CommonResult.data(feedingListService.listFeed(feedingListIdParam.getOrgId()));
    }

    /**
     * 获取料塔曲线
     *
     * @author wang
     * @date  2023/12/27 15:34
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取料塔曲线")
    @PostMapping("/modular/feedinglist/feedList")
    public CommonResult<List<FeedingListVo2>> feedList(@RequestBody Map<String,String> paramsMap) {
        return CommonResult.data(feedingListService.feedingList(paramsMap));
    }
}
